summaryrefslogtreecommitdiffstats
path: root/darwin
diff options
context:
space:
mode:
authorNathan Scott <nathans@redhat.com>2023-08-31 11:56:43 +1000
committerNathan Scott <nathans@redhat.com>2023-08-31 14:13:16 +1000
commitb74673fe37fd379fc350789e696470556776d815 (patch)
treecbe4f036962c439f9c07a9c96302f5908f6410b0 /darwin
parent214166a049c2a6ac454dbb37b85b04c039a6a17a (diff)
Rename ProcessList to ProcessTable throughout
Following up with some discusson from a few months back, where it was proposed that ProcessTable is a better name. This data structure is definitely not a list ... if it was one-dimensional it'd be a set, but in practice it has much more in common with a two-dimensional table. The Process table is a familiar operating system concept for many people too so it resonates a little in that way as well.
Diffstat (limited to 'darwin')
-rw-r--r--darwin/DarwinProcess.c12
-rw-r--r--darwin/DarwinProcess.h4
-rw-r--r--darwin/DarwinProcessTable.c (renamed from darwin/DarwinProcessList.c)42
-rw-r--r--darwin/DarwinProcessTable.h (renamed from darwin/DarwinProcessList.h)14
4 files changed, 36 insertions, 36 deletions
diff --git a/darwin/DarwinProcess.h b/darwin/DarwinProcess.h
index 89a0576d..496b179b 100644
--- a/darwin/DarwinProcess.h
+++ b/darwin/DarwinProcess.h
@@ -10,7 +10,7 @@ in the source distribution for its full text.
#include <sys/sysctl.h>
#include "Machine.h"
-#include "darwin/DarwinProcessList.h"
+#include "darwin/DarwinProcessTable.h"
#define PROCESS_FLAG_TTY 0x00000100
@@ -34,7 +34,7 @@ void Process_delete(Object* cast);
void DarwinProcess_setFromKInfoProc(Process* proc, const struct kinfo_proc* ps, bool exists);
-void DarwinProcess_setFromLibprocPidinfo(DarwinProcess* proc, DarwinProcessList* dpl, double timeIntervalNS);
+void DarwinProcess_setFromLibprocPidinfo(DarwinProcess* proc, DarwinProcessTable* dpt, double timeIntervalNS);
/*
* Scan threads for process state information.
diff --git a/darwin/DarwinProcessList.c b/darwin/DarwinProcessTable.c
index 1545600e..850b503f 100644
--- a/darwin/DarwinProcessList.c
+++ b/darwin/DarwinProcessTable.c
@@ -1,11 +1,11 @@
/*
-htop - DarwinProcessList.c
+htop - DarwinProcessTable.c
(C) 2014 Hisham H. Muhammad
Released under the GNU GPLv2+, see the COPYING file
in the source distribution for its full text.
*/
-#include "darwin/DarwinProcessList.h"
+#include "darwin/DarwinProcessTable.h"
#include <errno.h>
#include <libproc.h>
@@ -19,7 +19,7 @@ in the source distribution for its full text.
#include <sys/sysctl.h>
#include "CRT.h"
-#include "ProcessList.h"
+#include "ProcessTable.h"
#include "darwin/DarwinMachine.h"
#include "darwin/DarwinProcess.h"
#include "darwin/Platform.h"
@@ -28,7 +28,7 @@ in the source distribution for its full text.
#include "zfs/ZfsArcStats.h"
-static struct kinfo_proc* ProcessList_getKInfoProcs(size_t* count) {
+static struct kinfo_proc* ProcessTable_getKInfoProcs(size_t* count) {
int mib[4] = { CTL_KERN, KERN_PROC, KERN_PROC_ALL, 0 };
struct kinfo_proc* processes = NULL;
@@ -53,40 +53,40 @@ static struct kinfo_proc* ProcessList_getKInfoProcs(size_t* count) {
CRT_fatalError("Unable to get kinfo_procs");
}
-ProcessList* ProcessList_new(Machine* host, Hashtable* pidMatchList) {
- DarwinProcessList* this = xCalloc(1, sizeof(DarwinProcessList));
- Object_setClass(this, Class(ProcessList));
+ProcessTable* ProcessTable_new(Machine* host, Hashtable* pidMatchList) {
+ DarwinProcessTable* this = xCalloc(1, sizeof(DarwinProcessTable));
+ Object_setClass(this, Class(ProcessTable));
- ProcessList* super = &this->super;
- ProcessList_init(super, Class(DarwinProcess), host, pidMatchList);
+ ProcessTable* super = &this->super;
+ ProcessTable_init(super, Class(DarwinProcess), host, pidMatchList);
return super;
}
-void ProcessList_delete(Object* cast) {
- DarwinProcessList* this = (DarwinProcessList*) cast;
- ProcessList_done(&this->super);
+void ProcessTable_delete(Object* cast) {
+ DarwinProcessTable* this = (DarwinProcessTable*) cast;
+ ProcessTable_done(&this->super);
free(this);
}
-void ProcessList_goThroughEntries(ProcessList* super) {
+void ProcessTable_goThroughEntries(ProcessTable* super) {
const Machine* host = super->super.host;
const DarwinMachine* dhost = (const DarwinMachine*) host;
- DarwinProcessList* dpl = (DarwinProcessList*) super;
+ DarwinProcessTable* dpt = (DarwinProcessTable*) super;
bool preExisting = true;
struct kinfo_proc* ps;
size_t count;
DarwinProcess* proc;
/* Get the time difference */
- dpl->global_diff = 0;
+ dpt->global_diff = 0;
for (unsigned int i = 0; i < host->existingCPUs; ++i) {
for (size_t j = 0; j < CPU_STATE_MAX; ++j) {
- dpl->global_diff += dhost->curr_load[i].cpu_ticks[j] - dhost->prev_load[i].cpu_ticks[j];
+ dpt->global_diff += dhost->curr_load[i].cpu_ticks[j] - dhost->prev_load[i].cpu_ticks[j];
}
}
- const double time_interval_ns = Platform_schedulerTicksToNanoseconds(dpl->global_diff) / (double) host->activeCPUs;
+ const double time_interval_ns = Platform_schedulerTicksToNanoseconds(dpt->global_diff) / (double) host->activeCPUs;
/* We use kinfo_procs for initial data since :
*
@@ -95,13 +95,13 @@ void ProcessList_goThroughEntries(ProcessList* super) {
*
* We attempt to fill-in additional information with libproc.
*/
- ps = ProcessList_getKInfoProcs(&count);
+ ps = ProcessTable_getKInfoProcs(&count);
for (size_t i = 0; i < count; ++i) {
- proc = (DarwinProcess*)ProcessList_getProcess(super, ps[i].kp_proc.p_pid, &preExisting, DarwinProcess_new);
+ proc = (DarwinProcess*)ProcessTable_getProcess(super, ps[i].kp_proc.p_pid, &preExisting, DarwinProcess_new);
DarwinProcess_setFromKInfoProc(&proc->super, &ps[i], preExisting);
- DarwinProcess_setFromLibprocPidinfo(proc, dpl, time_interval_ns);
+ DarwinProcess_setFromLibprocPidinfo(proc, dpt, time_interval_ns);
if (proc->super.st_uid != ps[i].kp_eproc.e_ucred.cr_uid) {
proc->super.st_uid = ps[i].kp_eproc.e_ucred.cr_uid;
@@ -118,7 +118,7 @@ void ProcessList_goThroughEntries(ProcessList* super) {
super->totalTasks += 1;
if (!preExisting) {
- ProcessList_add(super, &proc->super);
+ ProcessTable_add(super, &proc->super);
}
}
diff --git a/darwin/DarwinProcessList.h b/darwin/DarwinProcessTable.h
index 56d6c1b5..7467bfd9 100644
--- a/darwin/DarwinProcessList.h
+++ b/darwin/DarwinProcessTable.h
@@ -1,7 +1,7 @@
-#ifndef HEADER_DarwinProcessList
-#define HEADER_DarwinProcessList
+#ifndef HEADER_DarwinProcessTable
+#define HEADER_DarwinProcessTable
/*
-htop - DarwinProcessList.h
+htop - DarwinProcessTable.h
(C) 2014 Hisham H. Muhammad
Released under the GNU GPLv2+, see the COPYING file
in the source distribution for its full text.
@@ -10,13 +10,13 @@ in the source distribution for its full text.
#include <mach/mach_host.h>
#include <sys/sysctl.h>
-#include "ProcessList.h"
+#include "ProcessTable.h"
-typedef struct DarwinProcessList_ {
- ProcessList super;
+typedef struct DarwinProcessTable_ {
+ ProcessTable super;
uint64_t global_diff;
-} DarwinProcessList;
+} DarwinProcessTable;
#endif

© 2014-2024 Faster IT GmbH | imprint | privacy policy
diff --git a/darwin/DarwinProcess.c b/darwin/DarwinProcess.c
index ec98341e..4f58832d 100644
--- a/darwin/DarwinProcess.c
+++ b/darwin/DarwinProcess.c
@@ -299,7 +299,7 @@ void DarwinProcess_setFromKInfoProc(Process* proc, const struct kinfo_proc* ps,
/* UNSET HERE :
*
* processor
* user (set at ProcessList level)
* nlwp
* percent_cpu
* percent_mem
@@ -362,7 +362,7 @@ void DarwinProcess_setFromKInfoProc(Process* proc, const struct kinfo_proc* ps,
proc->super.updated = true;
}
-void DarwinProcess_setFromLibprocPidinfo(DarwinProcess* proc, DarwinProcessList* dpl, double timeIntervalNS) {
+void DarwinProcess_setFromLibprocPidinfo(DarwinProcess* proc, DarwinProcessTable* dpt, double timeIntervalNS) {
struct proc_taskinfo pti;
if (sizeof(pti) == proc_pidinfo(Process_getPid(&proc->super), PROC_PIDTASKINFO, 0, &pti, sizeof(pti))) {
@@ -394,10 +394,10 @@ void DarwinProcess_setFromLibprocPidinfo(DarwinProcess* proc, DarwinProcessList*
proc->stime = system_time_ns;
proc->utime = user_time_ns;
- dpl->super.kernelThreads += 0; /*pti.pti_threads_system;*/
- dpl->super.userlandThreads += pti.pti_threadnum; /*pti.pti_threads_user;*/
- dpl->super.totalTasks += pti.pti_threadnum;
- dpl->super.runningTasks += pti.pti_numrunning;
+ dpt->super.kernelThreads += 0; /*pti.pti_threads_system;*/
+ dpt->super.userlandThreads += pti.pti_threadnum; /*pti.pti_threads_user;*/
+ dpt->super.totalTasks += pti.pti_threadnum;
+ dpt->super.runningTasks += pti.pti_numrunning;
}
}
@@ -299,7 +299,7 @@ void DarwinProcess_setFromKInfoProc(Process* proc, const struct kinfo_proc* ps,
*
* processor
- * user (set at ProcessList level)
+ * user (set at ProcessTable level)
* nlwp
* percent_cpu